@@ -65,8 +65,6 @@ def _publish_task(publish_args: str = '') -> DoitTask:
         DoitTask: doit task
 
     """
-    # See guide on publishing
-    #   https://github.com/KyleKing/calcipy/blob/dev/development/docs/DEVELOPER_GUIDE.md#publishing
     return debug_task([
         Interactive('poetry run nox --session build_dist build_check'),
         f'poetry publish {publish_args}',
@@ -102,13 +100,13 @@ def task_publish_test_pypi() -> DoitTask:
 # Check for stale packages
 
 
-def _auto_convert(cls, fields):  # type: ignore # noqa: ANN001, ANN202, CCR001
+def _auto_convert(_cls, fields):  # type: ignore # noqa: ANN001, ANN202, CCR001
     """Auto convert datetime attributes from string.
 
-    https://www.attrs.org/en/stable/extending.html#automatic-field-transformation-and-modification
+    Based on: https://www.attrs.org/en/stable/extending.html#automatic-field-transformation-and-modification
 
     Args:
-        cls: type?
+        _cls: unused class argument
         fields: `_HostedPythonPackageAttribtues`
 
     Returns:
